From ad3aec71ed7f8820e69fe55489368a19d0735ab5 Mon Sep 17 00:00:00 2001
From: Andreas Sturmlechner <asturm@gentoo.org>
Date: Sat, 11 Jul 2020 23:04:16 +0200
Subject: [PATCH] ECMAddTests.cmake: Skip ecm_add_test early if Qt5::Test is not available

Signed-off-by: Andreas Sturmlechner <asturm@gentoo.org>
---
 modules/ECMAddTests.cmake        | 9 +++++++++
 tests/ECMAddTests/CMakeLists.txt | 5 +++++
 2 files changed, 14 insertions(+)

diff --git a/modules/ECMAddTests.cmake b/modules/ECMAddTests.cmake
index 4bc7fb8..12825aa 100644
--- a/modules/ECMAddTests.cmake
+++ b/modules/ECMAddTests.cmake
@@ -81,6 +81,10 @@ function(ecm_add_test)
     message(FATAL_ERROR "ecm_add_test() called with multiple source files but without setting \"TEST_NAME\"")
   endif()
 
+  if(NOT TARGET Qt5::Test)
+    return()
+  endif()
+
   set(_testname ${ARG_NAME_PREFIX}${_targetname})
   set(gui_args)
   if(ARG_GUI)
@@ -122,6 +126,11 @@ function(ecm_add_tests)
   endif()
   set(test_names)
   set(target_names)
+
+  if(NOT TARGET Qt5::Test)
+    return()
+  endif()
+
   foreach(_test_source ${ARG_UNPARSED_ARGUMENTS})
     ecm_add_test(${_test_source}
       NAME_PREFIX ${ARG_NAME_PREFIX}
diff --git a/tests/ECMAddTests/CMakeLists.txt b/tests/ECMAddTests/CMakeLists.txt
index e77b33f..4e191fe 100644
--- a/tests/ECMAddTests/CMakeLists.txt
+++ b/tests/ECMAddTests/CMakeLists.txt
@@ -1,3 +1,8 @@
+if(NOT TARGET Qt5::Test)
+    message(STATUS "WARNING: skipping tests that require Qt5::Test")
+    return()
+endif()
+
 macro(add_check NAME)
     string(REPLACE "." "/" dir "${NAME}")
     string(REGEX REPLACE "[^.]*\\." "" proj "${NAME}")
-- 
2.27.0

